

% This function is called by the main Matlab program for 
% running imaging polarimetric self-calibration.
% This function does least-squares polarimetry:  estimation of the 
% objects' Stokes vectors and polarization parameters, given a 
% known or assumed set of  polarizer (analyser) angles. The function 
% also returns the MSE of this estimation.
%
% You are very welcome to use this code. For this, clearly acknowledge 
% the source of this code, and cite the paper that describes the algorithm:
% Y. Y. Schechner, "Self-Calibrating Imaging Polarimetry", 
% Proc. IEEE Int. Conference on Computational Photography (ICCP), 2015.
%
% (c) Copyright Yoav Schechner 2015. The matlab code is available for 
% non-commercial use and exploration.  For commercial use contact the
% author. The author is not liable for any damages or loss that might be 
% caused by use or connection to this code. 



function   [Object_matrix,object_angle_degrees,p_object,E]=object_polariz3(vector_of_angles,num_of_pixels,Idata_cs,subdata)


[P,inverseP]=analyzer_matrices(vector_of_angles,num_of_pixels);
hato=inverseP*Idata_cs;
Object_matrix=reshape(hato,3,num_of_pixels);

ac=Object_matrix(2,:)./Object_matrix(1,:);
as=Object_matrix(3,:)./Object_matrix(1,:);
object_vector=ac+i*as;
object_angle=angle(object_vector)/2;
object_angle_degrees=mod((object_angle*180/pi),180);
p_object=abs(object_vector);

Emat= (abs(P*Object_matrix-subdata)).^2;
E=mean(Emat(:));


