

% This function is called by the main Matlab program for running imaging polarimetric self-calibration 
% on the "Lab" or "Corridor" data sequences. 
% This function goes over all files in the experiment, and reads the image data
% in particular spatial rectangles. These rectangles had been pre-selected using a mouse. 
% The avera value of the image in each rectangle, over all frames, is then
% outputed in a matrix, Idata.
%
% You are very welcome to use this code. For this, clearly acknowledge 
% the source of this code, and cite the paper that describes the algorithm:
% Y. Y. Schechner, "Self-Calibrating Imaging Polarimetry", 
% Proc. IEEE Int. Conference on Computational Photography (ICCP), 2015.
%
% (c) Copyright Yoav Schechner 2015. The matlab code is available for 
% non-commercial use and exploration.  For commercial use contact the
% author. The author is not liable for any damages or loss that might be 
% caused by use or connection to this code. 



function [Idata,cangles]=read_selected_regions_lab(fprefix,cangles,rect_coord,acceptable_regions)

number_of_regions=size(rect_coord,2);

% Reading all the data in the rectangles
%
for picind=1:length(cangles),
    the_angle=cangles(picind);
    a=int2str(the_angle);
    if the_angle<10
        a0=['00' a];
    elseif the_angle<100
        a0=['0' a]; 
    else
        a0=a;
    end
    filename=[fprefix a0 '.bmp'];
    A=double(imread(filename));

    for regionind=1:number_of_regions,
        malben=rect_coord(:,regionind);
        u=malben(1); d=malben(2); l=malben(3); r=malben(4); 
        yarea=A(u:d,l:r);
        C(picind,regionind)=mean(yarea(:)); 
    end
end
    
    
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

% Reasonable regions, that don't have saturation or hard undervalues
%
for regionindex=1:length(acceptable_regions),
    regionind=acceptable_regions(regionindex);
    measured_intensities=C(:,regionind);
    Idata(:,regionindex)=measured_intensities;
end




%